@@ -10,16 +10,12 @@ enum SimpleEnum {
     C,
 }
 
-
 #[test]
 fn test_empty() {
     #[derive(TS)]
     enum Empty {}
-    
-    assert_eq!(
-        Empty::decl(),
-        "type Empty = never;"
-    )
+
+    assert_eq!(Empty::decl(), "type Empty = never;")
 }
 
 #[test]
